@@ -1,4 +1,4 @@
-// Gmsh - Copyright (C) 1997-2022 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2023 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file in the Gmsh root directory for license information.
 // Please report all issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
@@ -252,9 +252,17 @@ void onelab_cb(Fl_Widget *w, void *data)
 
   if(action == "compute" && (CTX::instance()->solver.autoSaveDatabase ||
                              CTX::instance()->solver.autoArchiveOutputFiles)) {
-    std::vector<std::string> split =
-      SplitFileName(GModel::current()->getFileName());
-    std::string db = split[0] + split[1] + ".db";
+    std::string db;
+    std::vector<onelab::string> ps;
+    onelab::server::instance()->get(ps, "Gmsh/DatabaseFileName");
+    if(ps.size() && ps[0].getValue().size()) {
+      db = ps[0].getValue();
+    }
+    else {
+      std::vector<std::string> split =
+        SplitFileName(GModel::current()->getFileName());
+      db = split[0] + split[1] + ".db";
+    }
     if(CTX::instance()->solver.autoArchiveOutputFiles)
       onelabUtils::archiveOutputFiles(db);
     if(CTX::instance()->solver.autoSaveDatabase) onelabUtils::saveDb(db);
@@ -1562,6 +1570,16 @@ void onelabGroup::closeTreeItem(const std::string &name)
   }
 }
 
+bool onelabGroup::isTreeItemOpen(const std::string &name) {
+  Fl_Tree_Item *n = _tree->find_item(name.c_str());
+  if (n != NULL) {
+    if(n->is_open()){
+      return true;
+    }
+  }
+  return false;
+}
+
 void onelabGroup::checkForErrors(const std::string &client)
 {
   if(Msg::GetErrorCount() > 0 && !CTX::instance()->expertMode) {
